%concatenates the small squares into bigger size*size squares
%and generates a list of normal vectors for the planes
function csMat = concatenate(sMat,size,fstepx,fstepy)
    global originx originy
    csMat = nan(length(sMat(:,1)),length(sMat(1,:)));
    
    %Normal Matrix has enough space for one normal vector per plane
    %Each row stores the plane's (x,y) and the X,Y,Z of the normal of that
    %plane
    %normalMat = nan(length(csMat(1,:))*length(csMat(:,1)) , 6);
    normalMat = nan(1,6);
    for j = 1:size:length(sMat(1,:))-size
        for i = 1:size:length(sMat(:,1))-size
            %Make sure we haven't already added current point to new mat
            if(isnan(csMat(i,j)))
                %check that size*size corners exist
                if(~isnan(sMat(i,j)) && ~isnan(sMat(i+size-1,j)) ... 
                   && ~isnan(sMat(i,j+size-1)) && ~isnan(sMat(i+size-1,j+size-1)))
                   csMat(i,j) = sMat(i,j);
                   csMat(i+size-1,j) = sMat(i+size-1,j);
                   csMat(i,j+size-1) = sMat(i,j+size-1);
                   csMat(i+size-1,j+size-1) = sMat(i+size-1,j+size-1);                   
               
                end              
            end            
        end                  
    end
   
    for i = 1:size:length(csMat(:,1))-size
        for j = 1:size:length(csMat(1,:))-size
            if(~isnan(csMat(i,j)))
                % Format of points X(1)-X(2)
                %                   |     |  
                %                   X(4)-X(3)     
                X = [i+fstepx i+size-1+fstepx ... 
                           i+size-1+fstepx i+fstepx];
                Y = [j+fstepy j+fstepy ...
                         j+size-1+fstepy j+size-1+fstepy];
                Z = [csMat(i,j) csMat(i+size-1,j) csMat(i+size-1,j+size-1) ...
                                        csMat(i,j+size-1)];
                %assign values to normal matrix
                Vertical = [X(4) Y(4) Z(4)] - [X(1) Y(1) Z(1)];
                Horizontal = [X(2) Y(2) Z(2)] - [X(1) Y(1) Z(1)];
                normal = cross(Vertical,Horizontal);
                %For quiver3, the x,y,z needs to be the centroid of the
                %plane that that x,y,z creates
 
                normalMat(1) = i + size/2; %x
                normalMat(2) = j + size/2; %y
                normalMat(3) = -mean(Z); %z
                normalMat(4) = normal(1); %u
                normalMat(5) = normal(2); %v
                normalMat(6) = normal(3); %w
                color = norms(normalMat);
                patch(X,Y,-Z,color)
                
            end
        end    
    end
end
    

